# Postman for Node

This library helps you send e-mails through the open source mail delivery
platform, [Postman](https://postman.prmail.vn) in Node.

## Installation

Install the library using [NPM](https://www.npmjs.com/):

```
$ npm install @postman/postman --save
```

## Usage

Sending an email is very simple. Just follow the example below. Before you can
begin, you'll need to login to your installation's web interface and generate
new API credentials.

```javascript
// Include the Postman library
var Postman = require('@postman/postman');

// Create a new Postman client using a server key generated using your
// installation's web interface
var client = new Postman.Client('https://postman.prmail.vn', 'your-api-key');

// Create a new message
var message = new Postman.SendMessage(client);

// Add some recipients
message.to('john@example.com');
message.to('mary@example.com');
message.cc('mike@example.com');
message.bcc('secret@awesomeapp.com');

// Specify who the message should be from - this must be from a verified domain
// on your mail server
message.from('test@test.postman.io');

// Set the subject
message.subject('Hi there!');

// Set the content for the e-mail
message.plainBody('Hello world!');
message.htmlBody('<p>Hello world!</p>');

// Add any custom headers
message.header('X-PHP-Test', 'value');

// Attach any files
message.attach('textmessage.txt', 'text/plain', 'Hello world!');

// Send the message and get the result
message.send()
  .then(function (result) {
    var recipients = result.recipients();
    // Loop through each of the recipients to get the message ID
    for (var email in recipients) {
      var message = recipients[email];
      console.log(message.id());    // Logs the message ID
      console.log(message.token()); // Logs the message's token
    }
  }).catch(function (error) {
    // Do something with the error
    console.log(error.code);
    console.log(error.message);
  });
```
